==> quarkus-vertx-http-1.2.0.CR1-sources.jar: io/quarkus/vertx/http/runtime/HttpConfiguration$$accessor.java <==
package io.quarkus.vertx.http.runtime;
public final class HttpConfiguration$$accessor {
    private HttpConfiguration$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_corsEnabled(Object __instance) {
        return ((HttpConfiguration)__instance).corsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_corsEnabled(Object __instance, boolean corsEnabled) {
        ((HttpConfiguration)__instance).corsEnabled = corsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static int get_port(Object __instance) {
        return ((HttpConfiguration)__instance).port;
    }
    @SuppressWarnings("unchecked")
    public static void set_port(Object __instance, int port) {
        ((HttpConfiguration)__instance).port = port;
    }
    @SuppressWarnings("unchecked")
    public static int get_testPort(Object __instance) {
        return ((HttpConfiguration)__instance).testPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_testPort(Object __instance, int testPort) {
        ((HttpConfiguration)__instance).testPort = testPort;
    }
    @SuppressWarnings("unchecked")
    public static Object get_host(Object __instance) {
        return ((HttpConfiguration)__instance).host;
    }
    @SuppressWarnings("unchecked")
    public static void set_host(Object __instance, Object host) {
        ((HttpConfiguration)__instance).host = (String)host;
    }
    @SuppressWarnings("unchecked")
    public static int get_sslPort(Object __instance) {
        return ((HttpConfiguration)__instance).sslPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_sslPort(Object __instance, int sslPort) {
        ((HttpConfiguration)__instance).sslPort = sslPort;
    }
    @SuppressWarnings("unchecked")
    public static int get_testSslPort(Object __instance) {
        return ((HttpConfiguration)__instance).testSslPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_testSslPort(Object __instance, int testSslPort) {
        ((HttpConfiguration)__instance).testSslPort = testSslPort;
    }
    @SuppressWarnings("unchecked")
    public static Object get_cors(Object __instance) {
        return ((HttpConfiguration)__instance).cors;
    }
    @SuppressWarnings("unchecked")
    public static void set_cors(Object __instance, Object cors) {
        ((HttpConfiguration)__instance).cors = (io.quarkus.vertx.http.runtime.cors.CORSConfig)cors;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ssl(Object __instance) {
        return ((HttpConfiguration)__instance).ssl;
    }
    @SuppressWarnings("unchecked")
    public static void set_ssl(Object __instance, Object ssl) {
        ((HttpConfiguration)__instance).ssl = (ServerSslConfig)ssl;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ioThreads(Object __instance) {
        return ((HttpConfiguration)__instance).ioThreads;
    }
    @SuppressWarnings("unchecked")
    public static void set_ioThreads(Object __instance, Object ioThreads) {
        ((HttpConfiguration)__instance).ioThreads = (java.util.OptionalInt)ioThreads;
    }
    @SuppressWarnings("unchecked")
    public static Object get_limits(Object __instance) {
        return ((HttpConfiguration)__instance).limits;
    }
    @SuppressWarnings("unchecked")
    public static void set_limits(Object __instance, Object limits) {
        ((HttpConfiguration)__instance).limits = (ServerLimitsConfig)limits;
    }
    @SuppressWarnings("unchecked")
    public static Object get_idleTimeout(Object __instance) {
        return ((HttpConfiguration)__instance).idleTimeout;
    }
    @SuppressWarnings("unchecked")
    public static void set_idleTimeout(Object __instance, Object idleTimeout) {
        ((HttpConfiguration)__instance).idleTimeout = (java.time.Duration)idleTimeout;
    }
    @SuppressWarnings("unchecked")
    public static Object get_body(Object __instance) {
        return ((HttpConfiguration)__instance).body;
    }
    @SuppressWarnings("unchecked")
    public static void set_body(Object __instance, Object body) {
        ((HttpConfiguration)__instance).body = (BodyConfig)body;
    }
    @SuppressWarnings("unchecked")
    public static Object get_encryptionKey(Object __instance) {
        return ((HttpConfiguration)__instance).encryptionKey;
    }
    @SuppressWarnings("unchecked")
    public static void set_encryptionKey(Object __instance, Object encryptionKey) {
        ((HttpConfiguration)__instance).encryptionKey = (java.util.Optional<String>)encryptionKey;
    }
    public static Object construct() {
        return new HttpConfiguration();
    }
}

==> quarkus-vertx-http-1.3.0.CR1-sources.jar: io/quarkus/vertx/http/runtime/HttpConfiguration$$accessor.java <==
package io.quarkus.vertx.http.runtime;
public final class HttpConfiguration$$accessor {
    private HttpConfiguration$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_corsEnabled(Object __instance) {
        return ((HttpConfiguration)__instance).corsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_corsEnabled(Object __instance, boolean corsEnabled) {
        ((HttpConfiguration)__instance).corsEnabled = corsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static int get_port(Object __instance) {
        return ((HttpConfiguration)__instance).port;
    }
    @SuppressWarnings("unchecked")
    public static void set_port(Object __instance, int port) {
        ((HttpConfiguration)__instance).port = port;
    }
    @SuppressWarnings("unchecked")
    public static int get_testPort(Object __instance) {
        return ((HttpConfiguration)__instance).testPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_testPort(Object __instance, int testPort) {
        ((HttpConfiguration)__instance).testPort = testPort;
    }
    @SuppressWarnings("unchecked")
    public static Object get_host(Object __instance) {
        return ((HttpConfiguration)__instance).host;
    }
    @SuppressWarnings("unchecked")
    public static void set_host(Object __instance, Object host) {
        ((HttpConfiguration)__instance).host = (String)host;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_hostEnabled(Object __instance) {
        return ((HttpConfiguration)__instance).hostEnabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_hostEnabled(Object __instance, boolean hostEnabled) {
        ((HttpConfiguration)__instance).hostEnabled = hostEnabled;
    }
    @SuppressWarnings("unchecked")
    public static int get_sslPort(Object __instance) {
        return ((HttpConfiguration)__instance).sslPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_sslPort(Object __instance, int sslPort) {
        ((HttpConfiguration)__instance).sslPort = sslPort;
    }
    @SuppressWarnings("unchecked")
    public static int get_testSslPort(Object __instance) {
        return ((HttpConfiguration)__instance).testSslPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_testSslPort(Object __instance, int testSslPort) {
        ((HttpConfiguration)__instance).testSslPort = testSslPort;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_proxyAddressForwarding(Object __instance) {
        return ((HttpConfiguration)__instance).proxyAddressForwarding;
    }
    @SuppressWarnings("unchecked")
    public static void set_proxyAddressForwarding(Object __instance, boolean proxyAddressForwarding) {
        ((HttpConfiguration)__instance).proxyAddressForwarding = proxyAddressForwarding;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_allowForwarded(Object __instance) {
        return ((HttpConfiguration)__instance).allowForwarded;
    }
    @SuppressWarnings("unchecked")
    public static void set_allowForwarded(Object __instance, boolean allowForwarded) {
        ((HttpConfiguration)__instance).allowForwarded = allowForwarded;
    }
    @SuppressWarnings("unchecked")
    public static Object get_insecureRequests(Object __instance) {
        return ((HttpConfiguration)__instance).insecureRequests;
    }
    @SuppressWarnings("unchecked")
    public static void set_insecureRequests(Object __instance, Object insecureRequests) {
        ((HttpConfiguration)__instance).insecureRequests = (io.quarkus.vertx.http.runtime.HttpConfiguration.InsecureRequests)insecureRequests;
    }
    @SuppressWarnings("unchecked")
    public static Object get_cors(Object __instance) {
        return ((HttpConfiguration)__instance).cors;
    }
    @SuppressWarnings("unchecked")
    public static void set_cors(Object __instance, Object cors) {
        ((HttpConfiguration)__instance).cors = (io.quarkus.vertx.http.runtime.cors.CORSConfig)cors;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ssl(Object __instance) {
        return ((HttpConfiguration)__instance).ssl;
    }
    @SuppressWarnings("unchecked")
    public static void set_ssl(Object __instance, Object ssl) {
        ((HttpConfiguration)__instance).ssl = (ServerSslConfig)ssl;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ioThreads(Object __instance) {
        return ((HttpConfiguration)__instance).ioThreads;
    }
    @SuppressWarnings("unchecked")
    public static void set_ioThreads(Object __instance, Object ioThreads) {
        ((HttpConfiguration)__instance).ioThreads = (java.util.OptionalInt)ioThreads;
    }
    @SuppressWarnings("unchecked")
    public static Object get_limits(Object __instance) {
        return ((HttpConfiguration)__instance).limits;
    }
    @SuppressWarnings("unchecked")
    public static void set_limits(Object __instance, Object limits) {
        ((HttpConfiguration)__instance).limits = (ServerLimitsConfig)limits;
    }
    @SuppressWarnings("unchecked")
    public static Object get_idleTimeout(Object __instance) {
        return ((HttpConfiguration)__instance).idleTimeout;
    }
    @SuppressWarnings("unchecked")
    public static void set_idleTimeout(Object __instance, Object idleTimeout) {
        ((HttpConfiguration)__instance).idleTimeout = (java.time.Duration)idleTimeout;
    }
    @SuppressWarnings("unchecked")
    public static Object get_body(Object __instance) {
        return ((HttpConfiguration)__instance).body;
    }
    @SuppressWarnings("unchecked")
    public static void set_body(Object __instance, Object body) {
        ((HttpConfiguration)__instance).body = (BodyConfig)body;
    }
    @SuppressWarnings("unchecked")
    public static Object get_encryptionKey(Object __instance) {
        return ((HttpConfiguration)__instance).encryptionKey;
    }
    @SuppressWarnings("unchecked")
    public static void set_encryptionKey(Object __instance, Object encryptionKey) {
        ((HttpConfiguration)__instance).encryptionKey = (java.util.Optional<String>)encryptionKey;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_soReusePort(Object __instance) {
        return ((HttpConfiguration)__instance).soReusePort;
    }
    @SuppressWarnings("unchecked")
    public static void set_soReusePort(Object __instance, boolean soReusePort) {
        ((HttpConfiguration)__instance).soReusePort = soReusePort;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_tcpQuickAck(Object __instance) {
        return ((HttpConfiguration)__instance).tcpQuickAck;
    }
    @SuppressWarnings("unchecked")
    public static void set_tcpQuickAck(Object __instance, boolean tcpQuickAck) {
        ((HttpConfiguration)__instance).tcpQuickAck = tcpQuickAck;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_tcpCork(Object __instance) {
        return ((HttpConfiguration)__instance).tcpCork;
    }
    @SuppressWarnings("unchecked")
    public static void set_tcpCork(Object __instance, boolean tcpCork) {
        ((HttpConfiguration)__instance).tcpCork = tcpCork;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_tcpFastOpen(Object __instance) {
        return ((HttpConfiguration)__instance).tcpFastOpen;
    }
    @SuppressWarnings("unchecked")
    public static void set_tcpFastOpen(Object __instance, boolean tcpFastOpen) {
        ((HttpConfiguration)__instance).tcpFastOpen = tcpFastOpen;
    }
    @SuppressWarnings("unchecked")
    public static Object get_domainSocket(Object __instance) {
        return ((HttpConfiguration)__instance).domainSocket;
    }
    @SuppressWarnings("unchecked")
    public static void set_domainSocket(Object __instance, Object domainSocket) {
        ((HttpConfiguration)__instance).domainSocket = (String)domainSocket;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_domainSocketEnabled(Object __instance) {
        return ((HttpConfiguration)__instance).domainSocketEnabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_domainSocketEnabled(Object __instance, boolean domainSocketEnabled) {
        ((HttpConfiguration)__instance).domainSocketEnabled = domainSocketEnabled;
    }
    public static Object construct() {
        return new HttpConfiguration();
    }
}
